# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`pe_databases`](#pe_databases): Tuning, maintenance for PE PostgreSQL.
* [`pe_databases::pg_repack`](#pe_databasespg_repack): Provides systemd timers to pg_repack tables in the pe-puppetdb database

### Defined types

* [`pe_databases::collect`](#pe_databasescollect): Create systemd units for repacking a given database type

### Tasks

* [`reset_pgrepack_schema`](#reset_pgrepack_schema): This task will remove and recreate the pg_repack extension

## Classes

### <a name="pe_databases"></a>`pe_databases`

Tuning, maintenance for PE PostgreSQL.

#### Parameters

The following parameters are available in the `pe_databases` class:

* [`manage_database_maintenance`](#manage_database_maintenance)
* [`disable_maintenance`](#disable_maintenance)
* [`install_dir`](#install_dir)
* [`scripts_dir`](#scripts_dir)
* [`facts_tables_repack_timer`](#facts_tables_repack_timer)
* [`catalogs_tables_repack_timer`](#catalogs_tables_repack_timer)
* [`other_tables_repack_timer`](#other_tables_repack_timer)
* [`manage_postgresql_settings`](#manage_postgresql_settings)
* [`manage_table_settings`](#manage_table_settings)
* [`reports_tables_repack_timer`](#reports_tables_repack_timer)
* [`resource_events_tables_repack_timer`](#resource_events_tables_repack_timer)

##### <a name="manage_database_maintenance"></a>`manage_database_maintenance`

Data type: `Boolean`

true or false (Default: true)
Manage the inclusion of the pg_repack class

Default value: ``true``

##### <a name="disable_maintenance"></a>`disable_maintenance`

Data type: `Boolean`

true or false (Default: false)
Disable or enable maintenance mode

Default value: ``false``

##### <a name="install_dir"></a>`install_dir`

Data type: `String[1]`

Directory to install module into (Default: "/opt/puppetlabs/pe_databases")

Default value: `'/opt/puppetlabs/pe_databases'`

##### <a name="scripts_dir"></a>`scripts_dir`

Data type: `String[1]`

Directory to install scripts into (Default: "${install_dir}/scripts")

Default value: `"${install_dir}/scripts"`

##### <a name="facts_tables_repack_timer"></a>`facts_tables_repack_timer`

Data type: `String[1]`

The Systemd timer for the pg_repack job affecting the 'facts' tables

Default value: `'Tue,Sat *-*-* 04:30:00'`

##### <a name="catalogs_tables_repack_timer"></a>`catalogs_tables_repack_timer`

Data type: `String[1]`

The Systemd timer for the pg_repack job affecting the 'catalog' tables

Default value: `'Sun,Thu *-*-* 04:30:00'`

##### <a name="other_tables_repack_timer"></a>`other_tables_repack_timer`

Data type: `String[1]`

The Systemd timer for the pg_repack job affecting the 'other' tables

Default value: `'*-*-20 05:30:00'`

##### <a name="manage_postgresql_settings"></a>`manage_postgresql_settings`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="manage_table_settings"></a>`manage_table_settings`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="reports_tables_repack_timer"></a>`reports_tables_repack_timer`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="resource_events_tables_repack_timer"></a>`resource_events_tables_repack_timer`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="pe_databasespg_repack"></a>`pe_databases::pg_repack`

Maintenance pg_repack

#### Parameters

The following parameters are available in the `pe_databases::pg_repack` class:

* [`disable_maintenance`](#disable_maintenance)
* [`jobs`](#jobs)
* [`facts_tables_repack_timer`](#facts_tables_repack_timer)
* [`catalogs_tables_repack_timer`](#catalogs_tables_repack_timer)
* [`other_tables_repack_timer`](#other_tables_repack_timer)
* [`reports_tables_repack_timer`](#reports_tables_repack_timer)
* [`resource_events_tables_repack_timer`](#resource_events_tables_repack_timer)

##### <a name="disable_maintenance"></a>`disable_maintenance`

Data type: `Boolean`

true or false (Default: false)
Disable or enable maintenance mode

Default value: ``false``

##### <a name="jobs"></a>`jobs`

Data type: `Integer`

How many jobs to run in parallel

Default value: `/`

##### <a name="facts_tables_repack_timer"></a>`facts_tables_repack_timer`

Data type: `String[1]`

The Systemd timer for the pg_repack job affecting the 'facts' tables

Default value: `$pe_databases::facts_tables_repack_timer`

##### <a name="catalogs_tables_repack_timer"></a>`catalogs_tables_repack_timer`

Data type: `String[1]`

The Systemd timer for the pg_repack job affecting the 'catalog' tables

Default value: `$pe_databases::catalogs_tables_repack_timer`

##### <a name="other_tables_repack_timer"></a>`other_tables_repack_timer`

Data type: `String[1]`

The Systemd timer for the pg_repack job affecting the 'other' tables

Default value: `$pe_databases::other_tables_repack_timer`

##### <a name="reports_tables_repack_timer"></a>`reports_tables_repack_timer`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="resource_events_tables_repack_timer"></a>`resource_events_tables_repack_timer`

Data type: `Optional[String]`



Default value: ``undef``

## Defined types

### <a name="pe_databasescollect"></a>`pe_databases::collect`

Create systemd units for repacking a given database type

#### Parameters

The following parameters are available in the `pe_databases::collect` defined type:

* [`database_type`](#database_type)
* [`command`](#command)
* [`disable_maintenance`](#disable_maintenance)
* [`on_cal`](#on_cal)

##### <a name="database_type"></a>`database_type`

Data type: `String`

The database to repack, uses titles from pg_repack.pp

Default value: `$title`

##### <a name="command"></a>`command`

Data type: `String`

defined in pg_repack.pp

Default value: ``undef``

##### <a name="disable_maintenance"></a>`disable_maintenance`

Data type: `Boolean`

to disable maintenance mode (Default: false)

Default value: ``false``

##### <a name="on_cal"></a>`on_cal`

Data type: `String`

values can be found in pg_repack.pp

Default value: ``undef``

## Tasks

### <a name="reset_pgrepack_schema"></a>`reset_pgrepack_schema`

This task will remove and recreate the pg_repack extension

**Supports noop?** false

